==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/forum/lang/forum_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Нет сообщений',

	// B
	'bouton_radio_articles_futurs' => 'только для новых материалов (текущие настройки не изменятся).',
	'bouton_radio_articles_tous' => 'для всех статей без исключения.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'для всех статей, кроме тех, в которых комментирование отключено.',
	'bouton_radio_enregistrement_obligatoire' => 'Только для зарегистрированных пользователей. Посетитель должен зарегистрироваться перед тем как оставить комментарий.',
	'bouton_radio_moderation_priori' => 'Комментарии публикуются на сайте после проверки администратором (пре-модерация).',
	'bouton_radio_modere_abonnement' => 'только пользователи сайта',
	'bouton_radio_modere_posteriori' => 'размещать без проверки',
	'bouton_radio_modere_priori' => 'проверять перед размещением',
	'bouton_radio_publication_immediate' => 'Новые комментарии сразу публикуются на сайте без проверки (пост-модерация). Администраторы потом могут удалить комментарии.',

	// D
	'documents_interdits_forum' => 'Запрещенно добавлять документы к сообщениям форума',

	// E
	'erreur_enregistrement_message' => 'Из-за технических проблем не получается сохранить ваш комментарий.',

	// F
	'form_pet_message_commentaire' => 'Комментарии',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'Вы больше не имеете доступа к этим форумам.',
	'forum_attention_dix_caracteres' => '<b>Внимание!</b> Сообщение должно быть не менее десяти символов.',
	'forum_attention_message_non_poste' => 'Внимание, ваш комментарий не опубликован на сайте.',
	'forum_attention_nb_caracteres_mini' => '<b>Внимание !</b> текст сообщения должен содержать не меньше @min@ символов.',
	'forum_attention_trois_caracteres' => '<b>Внимание!</b> Заголовок должен быть не менее трех символов.',
	'forum_attention_trop_caracteres' => '<b>Внимание!</b> Ваше сообщение содержит @compte@ символов, мы можем добавить ваш комментарий только если его размер не превышает @max@ символов.',
	'forum_avez_selectionne' => 'Вы выбрали:',
	'forum_cliquer_retour' => 'Нажмите  <a href=\'@retour_forum@\'>сюда</a> для продолжения.',
	'forum_forum' => 'комментарий',
	'forum_info_modere' => 'Комментарий проверяется администрацией сайта. Ваше сообщение появится после проверки администратором.',
	'forum_lien_hyper' => 'Ссылка',
	'forum_message' => 'Ваше сообщение',
	'forum_message_definitif' => 'Всё верно. Отправить!',
	'forum_message_trop_long' => 'Вы превысили максимальный размер сообщение, оно должно быть не более 20000 символов.',
	'forum_ne_repondez_pas' => 'Не отвечайте на это письмо - перейдите по ссылке:',
	'forum_page_url' => '(Если ваше сообщение относится к материалу, размещенному в Интернете, укажите название этой статьи  и ссылку на нее).',
	'forum_permalink' => 'Постоянная ссылка',
	'forum_poste_par' => '@parauteur@ прокомментировал вашу статью.', # MODIF
	'forum_poste_par_court' => 'Message posté@parauteur@.', # NEW
	'forum_poste_par_generique' => 'Message posté@parauteur@ (@objet@ « @titre@ »).', # NEW
	'forum_qui_etes_vous' => 'Кто вы?',
	'forum_saisie_texte_info' => 'Вы можете использовать следующую разметку текста <code>[->ссылка] {{жирный}} {курсив} <quote> <code></code> и теги HTML <code><q> <del> <ins></code>. Что бы создать новый абзац два раза нажмите enter.',
	'forum_texte' => 'Комментарий:',
	'forum_titre' => 'Тема:',
	'forum_url' => 'URL:',
	'forum_valider' => 'Подтвердите выбор',
	'forum_voir_avant' => 'Предварительный просмотр',
	'forum_votre_email' => 'Ваш e-mail',
	'forum_votre_nom' => 'Ваше имя',
	'forum_vous_enregistrer' => 'Оставлять комментарии могут только зарегистрированные пользователи. Если вы еще не зарегистрировались на сайте, вы можете',
	'forum_vous_inscrire' => 'зарегистрироваться.',

	// I
	'icone_bruler_message' => 'Отметить как спам',
	'icone_bruler_messages' => 'Отметить как спам',
	'icone_legitimer_message' => 'Отметить как НЕ спам',
	'icone_poster_message' => 'Оставить комментарий',
	'icone_suivi_forum' => 'Комментарии: @nb_forums@',
	'icone_suivi_forums' => 'Комментарии',
	'icone_supprimer_message' => 'Удалить',
	'icone_supprimer_messages' => 'Удалить',
	'icone_valider_message' => 'Опубликовать комментарий',
	'icone_valider_messages' => 'Опубликовать на сайте',
	'icone_valider_repondre_message' => 'Опубликовать и ответить',
	'info_1_message_forum' => '1 сообщение',
	'info_activer_forum_public' => 'Включить комментарии - выберите режим модерации для новых сообщений:',
	'info_appliquer_choix_moderation' => 'Применить этот тип модерации:',
	'info_config_forums_prive' => 'В административной части сайта доступны следующие форумы:',
	'info_config_forums_prive_admin' => 'Форум для администраторов сайта:',
	'info_config_forums_prive_global' => 'Форум для всех авторов:',
	'info_config_forums_prive_objets' => 'Форум, прикрепленный к каждой статье, новости, ссылочному сайту, и т. д.:',
	'info_desactiver_forum_public' => 'Отключить комментарии по сайту. Вы можете отдельно разрешить комментировать конкретные статьи, но в целом комментарии на сайте отключены.',
	'info_envoi_forum' => 'Отправлять комментарии авторам статей',
	'info_fonctionnement_forum' => 'Модерация комментариев:',
	'info_forums_liees_mot' => 'Комментарии относящиеся к этому ключу',
	'info_gauche_suivi_forum_2' => 'На странице <i>управление комментариями</i>  вы можете управлять комментариями и сообщениями на сайте.',
	'info_liens_syndiques_3' => 'комментария(ев)',
	'info_liens_syndiques_4' => 'необходимо',
	'info_liens_syndiques_5' => 'комментарий',
	'info_liens_syndiques_6' => 'необходимо',
	'info_liens_syndiques_7' => 'проверить',
	'info_liens_texte' => 'Ссылка(и) в тексте комментария',
	'info_liens_titre' => 'Ссылка(и) в названии комментария',
	'info_mode_fonctionnement_defaut_forum_public' => 'Настройки комментариев на сайте',
	'info_nb_messages_forum' => '@nb@ комментария(ев)',
	'info_option_email' => 'Оповещение о новом комментарии. Автор статьи может получать оповещение на емейл о новых комментариях к его статье. Укажите, для каких случаев необходимо включить эту возможность.',
	'info_pas_de_forum' => 'отключить комментарии',
	'info_question_visiteur_ajout_document_forum' => 'Если Вы хотите разрешить посетителям добавлять  файлы к комментариям - укажите список расширений файлов, которые можно добавлять (gif, jpg, png, mp3 и т.д.).',
	'info_question_visiteur_ajout_document_forum_format' => 'Если вы хотите разрешить загрузку всех типов файлов - поставьте звездочку. Что бы запретить загрузку файлов - оставьте поле пустым.
',
	'info_selectionner_message' => 'Выбрать комментарии :',
	'interface_formulaire' => 'Стандартный интерфейс',
	'interface_onglets' => 'Интерфейс с закладками',
	'item_activer_forum_administrateur' => 'Включить форум администраторов',
	'item_config_forums_prive_global' => 'Включить форум авторов',
	'item_config_forums_prive_objets' => 'Включить эти форумы',
	'item_desactiver_forum_administrateur' => 'Отключить форум администраторов',
	'item_non_config_forums_prive_global' => 'Отключить форум авторов',
	'item_non_config_forums_prive_objets' => 'отключить эти форумы',

	// L
	'label_selectionner' => 'Выбрать :',
	'lien_reponse_article' => 'Комментарий к статье',
	'lien_reponse_breve_2' => 'Комментарий к новости',
	'lien_reponse_message' => 'Ответить на сообщение',
	'lien_reponse_rubrique' => 'Комментарий к разделу',
	'lien_reponse_site_reference' => 'Комментарий к сайту',
	'lien_vider_selection' => 'Очистить выбранное',

	// M
	'messages_aucun' => 'Нет',
	'messages_meme_auteur' => 'Все комментарии этого автора',
	'messages_meme_email' => 'Все комментарии с этого емейла',
	'messages_meme_ip' => 'Все комментарии с этого IP',
	'messages_off' => 'Удаленные',
	'messages_perso' => 'Личные',
	'messages_privadm' => 'Администраторы',
	'messages_prive' => 'Внутренние',
	'messages_privoff' => 'Удаленные',
	'messages_privrac' => 'Общие',
	'messages_prop' => 'На проверке',
	'messages_publie' => 'Опубликовано',
	'messages_spam' => 'Спам',
	'messages_tous' => 'Все',

	// O
	'onglet_messages_internes' => 'Внутренние комментарии ',
	'onglet_messages_publics' => 'Комментарии на сайте',
	'onglet_messages_vide' => 'Комментарии без текста',

	// R
	'repondre_message' => 'Ответить на это сообщение',

	// S
	'statut_off' => 'Удалить',
	'statut_original' => 'Исходник',
	'statut_prop' => 'На проверке',
	'statut_publie' => 'Опубликовано',
	'statut_spam' => 'Спам',

	// T
	'text_article_propose_publication_forum' => 'Вы можете прокомментировать эту статью, используя прикрепленный форум (внизу страницы).',
	'texte_en_cours_validation' => 'Статьи, новости и комментарии на модерации.',
	'texte_en_cours_validation_forum' => 'Вы можете оставлять Ваши комментарии, используя прикрепленные к ним форумы',
	'texte_messages_publics' => 'Сообщение на сайте о:',
	'titre_cadre_forum_administrateur' => 'Форум для администраторов',
	'titre_cadre_forum_interne' => 'Внутренний форум',
	'titre_config_forums_prive' => 'Внутренние комментарии',
	'titre_forum' => 'Комментарии',
	'titre_forum_suivi' => 'Управление комментариями',
	'titre_page_forum_suivi' => 'Управление комментариями',
	'titre_selection_action' => 'Выбрать',
	'tout_voir' => 'Все сообщения',

	// V
	'voir_messages_objet' => 'просмотреть'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/forum/lang/forum_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Нет сообщений',

	// B
	'bouton_radio_articles_futurs' => 'только для новых материалов (текущие настройки не изменятся).',
	'bouton_radio_articles_tous' => 'для всех статей без исключения.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'для всех статей, кроме тех, в которых комментарии отключены.',
	'bouton_radio_enregistrement_obligatoire' => 'Только для зарегистрированных пользователей. Посетитель должен зарегистрироваться перед тем как оставить комментарий.',
	'bouton_radio_moderation_priori' => 'Комментарии публикуются на сайте после проверки администратором (пре-модерация).',
	'bouton_radio_modere_abonnement' => 'только пользователи сайта',
	'bouton_radio_modere_posteriori' => 'размещать без проверки',
	'bouton_radio_modere_priori' => 'проверять перед размещением',
	'bouton_radio_publication_immediate' => 'Новые комментарии публикуются на сайте без предварительной проверки (пост-модерация). Администраторы  могут удалить комментарии позже.',

	// D
	'documents_interdits_forum' => 'Запрещенно добавлять документы к сообщениям форума',

	// E
	'erreur_enregistrement_message' => 'Из-за технических проблем не получается сохранить ваш комментарий.',

	// F
	'form_pet_message_commentaire' => 'Комментарии',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'У вас больше нет доступа к данным форумам.',
	'forum_attention_dix_caracteres' => '<b>Внимание!</b> Сообщение должно быть не менее десяти символов.',
	'forum_attention_message_non_poste' => 'Внимание, ваш комментарий не опубликован на сайте.',
	'forum_attention_nb_caracteres_mini' => '<b>Внимание !</b> текст сообщения должен содержать не меньше @min@ символов.',
	'forum_attention_trois_caracteres' => '<b>Внимание!</b> Заголовок должен быть не менее трех символов.',
	'forum_attention_trop_caracteres' => '<b>Внимание!</b> Ваше сообщение содержит @compte@ символов, мы можем добавить ваш комментарий только если его размер не превышает @max@ символов.',
	'forum_avez_selectionne' => 'Вы выбрали:',
	'forum_cliquer_retour' => 'Нажмите  <a href=\'@retour_forum@\'>сюда</a> для продолжения.',
	'forum_forum' => 'комментарий',
	'forum_info_modere' => 'Все комментарии проверяются администрацией сайта. Ваше сообщение будет опубликовано после одобрения администратором.',
	'forum_lien_hyper' => 'Ссылка',
	'forum_message' => 'Ваше сообщение',
	'forum_message_definitif' => 'Всё верно. Отправить!',
	'forum_message_trop_long' => 'Вы превысили максимальный размер сообщение, оно должно быть не более 20000 символов.',
	'forum_ne_repondez_pas' => 'Не отвечайте на это письмо - перейдите по ссылке:',
	'forum_page_url' => '(Если ваше сообщение относится к материалу, размещенному в Интернете, укажите название этой статьи  и ссылку на нее).',
	'forum_permalink' => 'Постоянная ссылка',
	'forum_poste_par' => '@parauteur@ прокомментировал вашу статью « @titre@ ».',
	'forum_poste_par_court' => 'Комментарий разместил @parauteur@.',
	'forum_poste_par_generique' => 'Комментарий разместил @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Кто вы?',
	'forum_saisie_texte_info' => 'Вы можете использовать следующую разметку текста <code>[->ссылка] {{жирный}} {курсив} <quote> <code></code> и теги HTML <code><q> <del> <ins></code>. Что бы создать новый абзац два раза нажмите enter.',
	'forum_texte' => 'Комментарий:',
	'forum_titre' => 'Тема:',
	'forum_url' => 'URL:',
	'forum_valider' => 'Подтвердите выбор',
	'forum_voir_avant' => 'Предварительный просмотр',
	'forum_votre_email' => 'Ваш e-mail',
	'forum_votre_nom' => 'Ваше имя',
	'forum_vous_enregistrer' => 'Оставлять комментарии могут только зарегистрированные пользователи. Если вы еще не зарегистрировались на сайте, вы можете',
	'forum_vous_inscrire' => 'зарегистрироваться.',

	// I
	'icone_bruler_message' => 'Отметить как спам',
	'icone_bruler_messages' => 'Отметить как спам',
	'icone_legitimer_message' => 'Отметить как НЕ спам',
	'icone_poster_message' => 'Оставить комментарий',
	'icone_suivi_forum' => 'Комментарии: @nb_forums@',
	'icone_suivi_forums' => 'Комментарии',
	'icone_supprimer_message' => 'Удалить',
	'icone_supprimer_messages' => 'Удалить',
	'icone_valider_message' => 'Опубликовать комментарий',
	'icone_valider_messages' => 'Опубликовать на сайте',
	'icone_valider_repondre_message' => 'Опубликовать и ответить',
	'info_1_message_forum' => '1 сообщение',
	'info_activer_forum_public' => 'Включить комментарии - выберите режим модерации для новых сообщений:',
	'info_appliquer_choix_moderation' => 'Применить этот тип модерации:',
	'info_config_forums_prive' => 'В административной части сайта доступны следующие форумы:',
	'info_config_forums_prive_admin' => 'Форум для администраторов сайта:',
	'info_config_forums_prive_global' => 'Форум для всех авторов:',
	'info_config_forums_prive_objets' => 'Форум, прикрепленный к каждой статье, новости, ссылочному сайту, и т. д.:',
	'info_desactiver_forum_public' => 'Отключить комментарии по сайту. Вы можете отдельно разрешить комментировать конкретные статьи, но в целом комментарии на сайте отключены.',
	'info_envoi_forum' => 'Отправлять комментарии авторам статей',
	'info_fonctionnement_forum' => 'Модерация комментариев:',
	'info_forums_liees_mot' => 'Комментарии относящиеся к этому ключу',
	'info_gauche_suivi_forum_2' => 'На странице <i>управление комментариями</i>  вы можете управлять комментариями и сообщениями на сайте.',
	'info_liens_syndiques_3' => 'комментария(ев)',
	'info_liens_syndiques_4' => 'необходимо',
	'info_liens_syndiques_5' => 'комментарий',
	'info_liens_syndiques_6' => 'необходимо',
	'info_liens_syndiques_7' => 'проверить',
	'info_liens_texte' => 'Ссылка(и) в тексте комментария',
	'info_liens_titre' => 'Ссылка(и) в названии комментария',
	'info_mode_fonctionnement_defaut_forum_public' => 'Настройки комментариев на сайте',
	'info_nb_messages_forum' => '@nb@ комментария(ев)',
	'info_option_email' => 'Оповещение о новом комментарии. Автор статьи может получать оповещение на емейл о новых комментариях к его статье. Укажите, для каких случаев необходимо включить эту возможность.',
	'info_pas_de_forum' => 'отключить комментарии',
	'info_question_visiteur_ajout_document_forum' => 'Если Вы хотите разрешить посетителям добавлять  файлы к комментариям - укажите список расширений файлов, которые можно добавлять (gif, jpg, png, mp3 и т.д.).',
	'info_question_visiteur_ajout_document_forum_format' => 'Если вы хотите разрешить загрузку всех типов файлов - поставьте звездочку. Что бы запретить загрузку файлов - оставьте поле пустым.
',
	'info_selectionner_message' => 'Выбрать комментарии :',
	'interface_formulaire' => 'Стандартный интерфейс',
	'interface_onglets' => 'Интерфейс с закладками',
	'item_activer_forum_administrateur' => 'Включить форум администраторов',
	'item_config_forums_prive_global' => 'Включить форум авторов',
	'item_config_forums_prive_objets' => 'Включить эти форумы',
	'item_desactiver_forum_administrateur' => 'Отключить форум администраторов',
	'item_non_config_forums_prive_global' => 'Отключить форум авторов',
	'item_non_config_forums_prive_objets' => 'отключить эти форумы',

	// L
	'label_selectionner' => 'Выбрать :',
	'lien_reponse_article' => 'Комментарий к статье',
	'lien_reponse_breve_2' => 'Комментарий к новости',
	'lien_reponse_message' => 'Ответить на сообщение',
	'lien_reponse_rubrique' => 'Комментарий к разделу',
	'lien_reponse_site_reference' => 'Комментарий к сайту',
	'lien_vider_selection' => 'Очистить выбранное',

	// M
	'messages_aucun' => 'Нет',
	'messages_meme_auteur' => 'Все комментарии этого автора',
	'messages_meme_email' => 'Все комментарии с этого емейла',
	'messages_meme_ip' => 'Все комментарии с этого IP',
	'messages_off' => 'Удаленные',
	'messages_perso' => 'Личные',
	'messages_privadm' => 'Администраторы',
	'messages_prive' => 'Внутренние',
	'messages_privoff' => 'Удаленные',
	'messages_privrac' => 'Общие',
	'messages_prop' => 'На проверке',
	'messages_publie' => 'Опубликовано',
	'messages_spam' => 'Спам',
	'messages_tous' => 'Все',

	// O
	'onglet_messages_internes' => 'Внутренние комментарии ',
	'onglet_messages_publics' => 'Комментарии на сайте',
	'onglet_messages_vide' => 'Комментарии без текста',

	// R
	'repondre_message' => 'Ответить на это сообщение',

	// S
	'statut_off' => 'Удалить',
	'statut_original' => 'Исходник',
	'statut_prop' => 'На проверке',
	'statut_publie' => 'Опубликовано',
	'statut_spam' => 'Спам',

	// T
	'text_article_propose_publication_forum' => 'Вы можете прокомментировать эту статью, используя прикрепленный форум (внизу страницы).',
	'texte_en_cours_validation' => 'Статьи, новости и комментарии на модерации.',
	'texte_en_cours_validation_forum' => 'Вы можете оставлять Ваши комментарии, используя прикрепленные к ним форумы',
	'texte_messages_publics' => 'Сообщение на сайте о:',
	'titre_cadre_forum_administrateur' => 'Форум для администраторов',
	'titre_cadre_forum_interne' => 'Внутренний форум',
	'titre_config_forums_prive' => 'Внутренние комментарии',
	'titre_forum' => 'Комментарии',
	'titre_forum_suivi' => 'Управление комментариями',
	'titre_page_forum_suivi' => 'Управление комментариями',
	'titre_selection_action' => 'Выбрать',
	'tout_voir' => 'Все сообщения',

	// V
	'voir_messages_objet' => 'просмотреть'
);

?>
